@@ -258,6 +258,9 @@ df <- get_all_od_combinations(origins, destinations)
 
 ##### TESTS isochrone ------------------------
 
+library(profvis)
+
+
 # allocate RAM memory to Java
 options(java.parameters = "-Xmx8G")
 
@@ -271,23 +274,33 @@ data_path <- system.file("extdata/poa", package = "r5r")
 r5r_core <- setup_r5(data_path = data_path)
 
 # load origin/point of interest
-origin <- read.csv(file.path(data_path, "poa_hexgrid.csv"))[500,]
+origin <- read.csv(file.path(data_path, "poa_hexgrid.csv"))[700,]
 
-departure_datetime <- as.POSIXct("13-03-2019 14:00:00", format = "%d-%m-%Y %H:%M:%S")
+departure_datetime <- as.POSIXct("13-05-2019 14:00:00", format = "%d-%m-%Y %H:%M:%S")
 
 
 ###### with no destinations input
 
 iso <- isochrone(r5r_core,
                  origin = origin,
-                 mode = c("transit"),
+                 mode = c("WALK", "TRANSIT"),
                  departure_datetime = departure_datetime,
-                 cutoffs = seq(10, 100, 10)
+                 cutoffs = c(0, 15, 30, 45, 60)
+                 #, sample_size = .8
                  )
-
+plot(iso['isochrone'])
 head(iso)
 
 
+profvis({
+  iso <- isochrone(r5r_core,
+                   origin = origin,
+                   mode = c("WALK", "TRANSIT"),
+                   departure_datetime = departure_datetime,
+                   cutoffs = c(0, 15, 30, 45, 60, 75, 90, 120)
+  )
+})
+
 # streets <- r5r::street_network_to_sf(r5r_core)
 
 ggplot() +
@@ -652,7 +665,7 @@ mapview(street_net) + points_sf
 ##### Coverage ------------------------
 library(covr)
 library(testthat)
-library(r5r)
+# library(r5r)
 Sys.setenv(NOT_CRAN = "true")
 
 
@@ -660,6 +673,7 @@ Sys.setenv(NOT_CRAN = "true")
 covr::function_coverage(fun=r5r::download_r5, test_file("tests/testthat/test-download_r5.R"))
 covr::function_coverage(fun=r5r::setup_r5, test_file("tests/testthat/test-setup_r5.R"))
 a <- covr::function_coverage(fun=r5r::travel_time_matrix, test_file("tests/testthat/test-travel_time_matrix.R"))
+a <- covr::function_coverage(fun=r5r::isochrone, test_file("tests/testthat/test-isochrone.R"))
 covr::function_coverage(fun=r5r::detailed_itineraries, test_file("tests/testthat/test-detailed_itineraries.R"))
 a <- covr::function_coverage(fun=r5r::expanded_travel_time_matrix, test_file("tests/testthat/test-expanded_travel_time_matrix.R"))
 a <- covr::function_coverage(fun=r5r::pareto_frontier, test_file("tests/testthat/test-pareto_frontier.R"))
@@ -699,16 +713,11 @@ Sys.setenv(NOT_CRAN = "true")
 r5r_cov <- covr::package_coverage(path = ".", type = "tests")
 r5r_cov
 
-saveRDS(r5r_cov3, file = './tests/tests_rafa/r5r_coverage.rds')
-
-as.data.frame(r5r_cov3)[, c(1:3, 5, 11)]
+covr::report()
 
 zeroCov <- covr::zero_coverage(a)
 
 
-x <- as.data.frame(r5r_cov)
-covr::codecov( coverage = r5r_cov, token ='2a7013e9-6562-4011-beb9-168e922c4c84' )
-
 
 
 
